@@ -485,11 +485,24 @@ async fn create_ws_client(
             .unwrap()
             .clone();
         let mut lock = lock.lock().await;
-        if !lock.owns_lock() {
-            lock.lock_with_pid().unwrap();
-            tokio::time::sleep(Duration::from_millis(interval)).await;
+        let mut i = 0;
+        while !lock.owns_lock() {
+            i += 1;
+            debug!(
+                "{} {} {} try_lock_with_pid() the {}th time",
+                exchange, market_type, msg_type, i
+            );
+            if lock.try_lock_with_pid().is_ok() {
+                break;
+            } else {
+                tokio::time::sleep(std::time::Duration::from_millis(
+                    rand::random::<u64>() % 90 + 11,
+                ))
+                .await; // give chances to other tasks
+            }
         }
         let ws_client = create_ws_client_internal(exchange, market_type, tx).await;
+        tokio::time::sleep(Duration::from_millis(interval)).await;
         if lock.owns_lock() {
             lock.unlock().unwrap();
         }
